@@ -42,7 +42,7 @@ After installing the CLI, you can run simple_deploy again.
 """
 
 platformshconfig_not_installed = """
-In order to deploy to Platform.sh, you need to install the package `platformshoconfig`.
+In order to deploy to Platform.sh, you need to install the package `platformshconfig`.
 To do this, run the following command, or its equivalent in your project:
     pip install platformshconfig
 After installing this package, you can run simple_deploy again.
@@ -190,4 +190,4 @@ def success_msg_automate_all(deployed_url):
           your deployment.
 
     """)
-    return msg
\ No newline at end of file
+    return msg
